pub enum TranslationStatus {
Unchanged,
Lossless,
Lossy,
}Expand description
Coarse translation outcome.
Variants
Unchanged
The output is byte-identical to the input and no diagnostics or losses were recorded.
Lossless
The output changed without known loss.
Lossy
Translation changed source spelling, skipped unsupported input, or recorded diagnostics.